@@ -87,7 +87,7 @@ def load_medical_costs():
     return fetch_dataset('insurance')
 
 def load_stroke():
-    return fetch_dataset('stroke')
+    return fetch_dataset('stroke-data')
 
 def load_wind_prediction():
     return fetch_dataset('wind-dataset')
